@@ -398,10 +398,6 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
                 'type': 'string',
                 'description': 'Redirect to this URL when not logged in.',
             },
-            'housekeeping_bitmaps_enabled': {
-                'type': 'boolean',
-                'description': 'Enable Git pack file bitmap creation.',
-            },
             'housekeeping_enabled': {
                 'type': 'boolean',
                 'description': 'Enable or disable git housekeeping.',
@@ -506,7 +502,7 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
                 'description': 'Minimum capacity to be available before scheduling more mirrors preemptively',
             },
             'mirror_max_capacity': {  # >= PREMIUM, SILVER
-                'type': 'string',
+                'type': 'integer',
                 'description': 'Maximum number of mirrors that can be synchronizing at the same time.',
             },
             'mirror_max_delay': {  # >= PREMIUM, SILVER
@@ -586,7 +582,7 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
                                'silent disk corruption issues.',
             },
             'repository_size_limit': {  # >= PREMIUM, SILVER
-                'type': 'string',
+                'type': 'integer',
                 'description': 'Size limit per repository (MB)',
             },
             'repository_storages': {
@@ -767,11 +763,13 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
         'dependencies': {
             'akismet_enabled': ['akismet_api_key'],
             'domain_blacklist_enabled': ['domain_blacklist'],
+            'elasticsearch_aws': ['elasticsearch_aws_region'],
+            'elasticsearch_indexing': ['elasticsearch_url'],
             'enforce_terms': ['terms'],
             'external_auth_client_cert': ['external_auth_client_key'],
             'external_authorization_service_enabled': ['external_authorization_service_timeout',
                                                        'external_authorization_service_url'],
-            'housekeeping_enabled': ['housekeeping_bitmaps_enabled', 'housekeeping_full_repack_period',
+            'housekeeping_enabled': ['housekeeping_full_repack_period',
                                      'housekeeping_gc_period', 'housekeeping_incremental_repack_period'],
             'metrics_enabled': ['metrics_host', 'metrics_method_call_threshold', 'metrics_packet_size',
                                 'metrics_pool_size', 'metrics_port', 'metrics_sample_interval', 'metrics_timeout'],
