@@ -225,7 +225,7 @@ class GitLabracadabraObject(object):
                             self._name, param_name, None, target_value)
                 return
             current_value = None
-        if current_value != target_value:
+        if current_value != target_value or skip_save:
             if 'dependencies' in self.SCHEMA and param_name in self.SCHEMA['dependencies']:
                 for dependency in self.SCHEMA['dependencies'][param_name]:
                     process_method = getattr(self, '_process_' + dependency, self._process_param)
